//
// OpenVRML
//
// Copyright 2001  Henri Manson
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//

package vrml;

/**
 * Parent class of all VRML fields.
 */
public abstract class Field implements Cloneable {
    /**
     * Indicates whether the field is an eventOut or not.
     */
    private boolean isEventOut = false;

    /**
     * Indicates whether the field is an eventIn or not.
     */
    private boolean isEventIn = false;

    /**
     * Indicates whether the field is an exposedField or not.
     */
    private boolean isExposedField = false;

    /**
     * Stores a pointer to a VrmlField object on the C++ side.
     */
    private int FieldPtr;

    public native Object clone();
}
